Reading and plotting data from the ISMN
=======================================

This example shows how to initialise a reader, select networks, stations and iterate over sensors to read data and
extract meta data.

.. include::
   ./examples/index.rst

